@@ -6,7 +6,7 @@ from __future__ import division, print_function, absolute_import
 
 __author__ = "Marek Rudnicki"
 
-__version__ = "0.3.1"
+__version__ = "0.4"
 
 import os
 import sys
@@ -29,13 +29,14 @@ if 'THlog' in os.environ:
     else:
         level = os.environ['THlog'].upper()
 
-    logger = logging.getLogger()
+    logger = logging.getLogger('thorns')
     logger.setLevel(level)
 
 
 
 import thorns.util
 import thorns.waves
+import thorns.io
 
 
 from thorns.spikes import (
